==> jc-1.4.0.tar.gz: java/awt/dnd/DropTargetDragEvent.h <==
// public class java.awt.dnd.DropTargetDragEvent

// class file dependencies
// @dep_class 10ddf6b8d4a3e1a2 java_awt_dnd_DropTargetDragEvent
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DropTargetEvent

#include "java/awt/dnd/DropTargetEvent.h"

#ifndef _JC_java_awt_dnd_DropTargetDragEvent_H_
#define _JC_java_awt_dnd_DropTargetDragEvent_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$sub_refs	_jc_java_awt_dnd_DropTargetDragEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs	_jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$refs	_jc_java_awt_dnd_DropTargetDragEvent$refs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$nonrefs	_jc_java_awt_dnd_DropTargetDragEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$object	_jc_java_awt_dnd_DropTargetDragEvent$object;

typedef struct _jc_java_awt_dnd_DropTargetDragEvent$fields_struct	_jc_java_awt_dnd_DropTargetDragEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vmethods	_jc_java_awt_dnd_DropTargetDragEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vtable	_jc_java_awt_dnd_DropTargetDragEvent$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vtype	_jc_java_awt_dnd_DropTargetDragEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DropTargetDragEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DropTargetDragEvent$fields_struct _jc_java_awt_dnd_DropTargetDragEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$_init$a00e7937b310ea39(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_dnd_DropTargetContext$object *, struct _jc_java_awt_Point$object *, jint, jint);

// Virtual methods
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$acceptDrag$059f5fe0542ba4c8(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, jint);
extern _jc_object_array *_jc_java_awt_dnd_DropTargetDragEvent$method$getCurrentDataFlavors$ad8c33144f5f4e47(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern struct _jc_object *_jc_java_awt_dnd_DropTargetDragEvent$method$getCurrentDataFlavorsAsList$88157d1e99d2cb02(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern jint _jc_java_awt_dnd_DropTargetDragEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern struct _jc_java_awt_Point$object *_jc_java_awt_dnd_DropTargetDragEvent$method$getLocation$d1bc48ab096da51c(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern jint _jc_java_awt_dnd_DropTargetDragEvent$method$getSourceActions$44890a2fb3cc6b8e(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
extern jboolean _jc_java_awt_dnd_DropTargetDragEvent$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$rejectDrag$ad6390fe2e377714(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$acceptDrag$059f5fe0542ba4c8;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getCurrentDataFlavors$ad8c33144f5f4e47;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getCurrentDataFlavorsAsList$88157d1e99d2cb02;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getLocation$d1bc48ab096da51c;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getSourceActions$44890a2fb3cc6b8e;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$isDataFlavorSupported$9e698abce62becef;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$rejectDrag$ad6390fe2e377714;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetDragEvent$vmethods {
	void	(*acceptDrag$059f5fe0542ba4c8)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, jint);
	_jc_object_array	*(*getCurrentDataFlavors$ad8c33144f5f4e47)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	struct _jc_object	*(*getCurrentDataFlavorsAsList$88157d1e99d2cb02)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	struct _jc_java_awt_Point$object	*(*getLocation$d1bc48ab096da51c)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	jint	(*getSourceActions$44890a2fb3cc6b8e)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *);
	void	(*rejectDrag$ad6390fe2e377714)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *);
};

// Vtable
struct _jc_java_awt_dnd_DropTargetDragEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DropTargetEvent$vmethods	java_awt_dnd_DropTargetEvent;
	_jc_java_awt_dnd_DropTargetDragEvent$vmethods	java_awt_dnd_DropTargetDragEvent;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetDragEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetDragEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetDragEvent$sub_refs {
	struct _jc_java_awt_Point$object	*location;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetDragEvent$refs {
    _jc_java_awt_dnd_DropTargetDragEvent$sub_refs	java_awt_dnd_DropTargetDragEvent;
    _jc_java_awt_dnd_DropTargetEvent$sub_refs	java_awt_dnd_DropTargetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs {
	jint	dropAction;
	jint	srcActions;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetDragEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	java_awt_dnd_DropTargetEvent;
    _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs	java_awt_dnd_DropTargetDragEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetDragEvent$object {
	_jc_java_awt_dnd_DropTargetDragEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetDragEvent$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetDragEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetDragEvent$vtype _jc_java_awt_dnd_DropTargetDragEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetDragEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetDragEvent$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetDragEvent_H_ */

==> jc-1.4.6.tar.gz: java/awt/dnd/DropTargetDragEvent.h <==
// public class java.awt.dnd.DropTargetDragEvent

// class file dependencies
// @dep_class 10ddf6b8d4a3e1a2 java_awt_dnd_DropTargetDragEvent
// @dep_class fb6fee3e34aaae16 java_awt_dnd_DropTargetEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_dnd_DropTargetEvent

#include "java/awt/dnd/DropTargetEvent.h"

#ifndef _JC_java_awt_dnd_DropTargetDragEvent_H_
#define _JC_java_awt_dnd_DropTargetDragEvent_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_datatransfer_DataFlavor$object;
struct _jc_java_awt_dnd_DropTargetContext$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$sub_refs	_jc_java_awt_dnd_DropTargetDragEvent$sub_refs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs	_jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$refs	_jc_java_awt_dnd_DropTargetDragEvent$refs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$nonrefs	_jc_java_awt_dnd_DropTargetDragEvent$nonrefs;
typedef struct _jc_java_awt_dnd_DropTargetDragEvent$object	_jc_java_awt_dnd_DropTargetDragEvent$object;

typedef struct _jc_java_awt_dnd_DropTargetDragEvent$fields_struct	_jc_java_awt_dnd_DropTargetDragEvent$fields_struct;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vmethods	_jc_java_awt_dnd_DropTargetDragEvent$vmethods;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vtable	_jc_java_awt_dnd_DropTargetDragEvent$vtable;
typedef const struct _jc_java_awt_dnd_DropTargetDragEvent$vtype	_jc_java_awt_dnd_DropTargetDragEvent$vtype;

// Class fields structure
struct _jc_java_awt_dnd_DropTargetDragEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_dnd_DropTargetDragEvent$fields_struct _jc_java_awt_dnd_DropTargetDragEvent$class_fields;

// Constructors
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$_init$a00e7937b310ea39(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_dnd_DropTargetContext$object *, struct _jc_java_awt_Point$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$acceptDrag$059f5fe0542ba4c8(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, jint) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_awt_dnd_DropTargetDragEvent$method$getCurrentDataFlavors$ad8c33144f5f4e47(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_awt_dnd_DropTargetDragEvent$method$getCurrentDataFlavorsAsList$88157d1e99d2cb02(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DropTargetDragEvent$method$getDropAction$edda4aeecf125b6a(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Point$object *_jc_java_awt_dnd_DropTargetDragEvent$method$getLocation$d1bc48ab096da51c(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_dnd_DropTargetDragEvent$method$getSourceActions$44890a2fb3cc6b8e(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_dnd_DropTargetDragEvent$method$isDataFlavorSupported$9e698abce62becef(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_dnd_DropTargetDragEvent$method$rejectDrag$ad6390fe2e377714(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$acceptDrag$059f5fe0542ba4c8;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getCurrentDataFlavors$ad8c33144f5f4e47;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getCurrentDataFlavorsAsList$88157d1e99d2cb02;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getDropAction$edda4aeecf125b6a;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getLocation$d1bc48ab096da51c;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$getSourceActions$44890a2fb3cc6b8e;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$isDataFlavorSupported$9e698abce62becef;
extern _jc_method _jc_java_awt_dnd_DropTargetDragEvent$method_info$rejectDrag$ad6390fe2e377714;

// Virtual methods structure
struct _jc_java_awt_dnd_DropTargetDragEvent$vmethods {
	void	(*acceptDrag$059f5fe0542ba4c8)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, jint) _JC_JCNI_ATTR;
	_jc_object_array	*(*getCurrentDataFlavors$ad8c33144f5f4e47)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getCurrentDataFlavorsAsList$88157d1e99d2cb02)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getDropAction$edda4aeecf125b6a)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Point$object	*(*getLocation$d1bc48ab096da51c)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	jint	(*getSourceActions$44890a2fb3cc6b8e)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isDataFlavorSupported$9e698abce62becef)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *, struct _jc_java_awt_datatransfer_DataFlavor$object *) _JC_JCNI_ATTR;
	void	(*rejectDrag$ad6390fe2e377714)(_jc_env *, struct _jc_java_awt_dnd_DropTargetDragEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_dnd_DropTargetDragEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_dnd_DropTargetEvent$vmethods	java_awt_dnd_DropTargetEvent;
	_jc_java_awt_dnd_DropTargetDragEvent$vmethods	java_awt_dnd_DropTargetDragEvent;
};

// Vtype
struct _jc_java_awt_dnd_DropTargetDragEvent$vtype {
	_jc_type			type;
	_jc_java_awt_dnd_DropTargetDragEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetDragEvent$sub_refs {
	struct _jc_java_awt_Point$object	*location;
};

// Reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetDragEvent$refs {
    _jc_java_awt_dnd_DropTargetDragEvent$sub_refs	java_awt_dnd_DropTargetDragEvent;
    _jc_java_awt_dnd_DropTargetEvent$sub_refs	java_awt_dnd_DropTargetEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs {
	jint	dropAction;
	jint	srcActions;
};

// Non-reference instance fields (object)
struct _jc_java_awt_dnd_DropTargetDragEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_dnd_DropTargetEvent$sub_nonrefs	java_awt_dnd_DropTargetEvent;
    _jc_java_awt_dnd_DropTargetDragEvent$sub_nonrefs	java_awt_dnd_DropTargetDragEvent;
};

// Object instance structure
struct _jc_java_awt_dnd_DropTargetDragEvent$object {
	_jc_java_awt_dnd_DropTargetDragEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_dnd_DropTargetDragEvent$vtype	*vtype;
	_jc_java_awt_dnd_DropTargetDragEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_dnd_DropTargetDragEvent$vtype _jc_java_awt_dnd_DropTargetDragEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_dnd_DropTargetDragEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_dnd_DropTargetDragEvent$class_object;

#endif	/* _JC_java_awt_dnd_DropTargetDragEvent_H_ */
